==> jetpack.15.1.1.zip: jetpack/jetpack_vendor/automattic/jetpack-post-list/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.8.31] - 2025-10-06
### Changed
- Update dependencies. [#45349]

## [0.8.30] - 2025-09-22
### Changed
- Update dependencies. [#44615]

## [0.8.29] - 2025-09-19
### Changed
- Update package dependencies. [#45173] [#45229]

## [0.8.28] - 2025-09-08
### Changed
- Update package dependencies. [#45027]

## [0.8.27] - 2025-08-14
### Changed
- Update package dependencies. [#44701]

## [0.8.26] - 2025-08-11
### Changed
- Update package dependencies. [#44677]

## [0.8.25] - 2025-08-04
### Changed
- Update dependencies. [#44583]

## [0.8.24] - 2025-07-28
### Changed
- Internal updates.

## [0.8.23] - 2025-07-21
### Changed
- Tests: Update class used in Slideshow block. [#44099]

## [0.8.22] - 2025-07-14
### Changed
- Update dependencies. [#44229]

## [0.8.21] - 2025-07-07
### Changed
- Update package dependencies. [#44148]

## [0.8.20] - 2025-06-30
### Changed
- Update dependencies. [#44061]

## [0.8.19] - 2025-06-23
### Changed
- Update dependencies. [#44002]
- Update package dependencies. [#44020]

## [0.8.18] - 2025-06-05
### Changed
- Update dependencies. [#43751]

## [0.8.17] - 2025-06-02
### Changed
- Update dependencies. [#43068]

## [0.8.16] - 2025-05-26
### Changed
- Update package dependencies. [#43578]

## [0.8.15] - 2025-05-22
### Changed
- Update dependencies. [#43068]

## [0.8.14] - 2025-05-05
### Changed
- Update package dependencies. [#43326]

## [0.8.13] - 2025-04-28
### Changed
- Internal updates.

## [0.8.12] - 2025-04-14
### Changed
- Update dependencies. [#43001]

## [0.8.11] - 2025-04-07
### Changed
- Linting: First pass of style coding standards. [#42734]
- Update dependencies. [#42820]
- Update package dependencies. [#42809]

## [0.8.10] - 2025-03-21
### Changed
- Internal updates.

## [0.8.9] - 2025-03-18
### Changed
- Update dependencies. [#42545]

## [0.8.8] - 2025-03-17
### Changed
- Internal updates.

## [0.8.7] - 2025-03-17
### Changed
- Social: Change the query parameter to open Jetpack sidebar on editor load. [#42364]

## [0.8.6] - 2025-03-12
### Changed
- Internal updates.

## [0.8.5] - 2025-03-10
### Fixed
- Exclude unit tests from published package. [#42190]

## [0.8.4] - 2025-03-03
### Changed
- Update package dependencies. [#42163]

## [0.8.3] - 2025-02-24
### Changed
- Update dependencies.

## [0.8.2] - 2025-02-17
### Changed
- Update dependencies.

## [0.8.1] - 2025-02-10
### Changed
- Updated package dependencies. [#41491]

## [0.8.0] - 2025-02-03
### Added
- Post List: Add a Copy Link Quick Action. [#41305]

## [0.7.3] - 2025-01-13
### Fixed
- Pages and Posts: Fix the layout on mobile when details are open. [#40872]

## [0.7.2] - 2024-12-16
### Changed
- Internal updates.

## [0.7.1] - 2024-11-25
### Changed
- Updated dependencies. [#40286]

## [0.7.0] - 2024-11-18
### Removed
- General: Update minimum PHP version to 7.2. [#40147]

## [0.6.5] - 2024-11-04
### Added
- Enable test coverage. [#39961]

## [0.6.4] - 2024-10-29
### Changed
- Internal updates.

## [0.6.3] - 2024-08-23
### Changed
- Updated package dependencies. [#39004]

## [0.6.2] - 2024-04-08
### Changed
- Internal updates.

## [0.6.1] - 2024-03-18
### Changed
- Internal updates.

## [0.6.0] - 2024-02-26
### Changed
- Social Notes: Added the post list enhancements [#35819]

## [0.5.1] - 2023-11-24
### Changed
- Replaced usage of substr() with str_starts_with() and str_ends_with(). [#34207]

## [0.5.0] - 2023-11-20
### Changed
- Updated required PHP version to >= 7.0. [#34192]

## [0.4.6] - 2023-08-28
### Changed
- Updated package dependencies. [#32605]

## [0.4.5] - 2023-04-10
### Added
- Add Jetpack Autoloader package suggestion. [#29988]

## [0.4.4] - 2023-02-20
### Changed
- Minor internal updates.

## [0.4.3] - 2022-12-06
### Changed
- Updated package dependencies. [#27688]

## [0.4.2] - 2022-11-28
### Changed
- Updated package dependencies. [#27043]

## [0.4.1] - 2022-09-20
### Changed
- Updated package dependencies.

## [0.4.0] - 2022-08-30
### Changed
- Rebrand Publicize to Jetpack Social [#25787]
- Updated package dependencies. [#25158]

## [0.3.1] - 2022-07-06
### Changed
- PHPCS: fix `WordPress.Security.ValidatedSanitizedInput`. [#23942]
- Renaming master to trunk. [#24661]
- Updated package dependencies. [#24045]

## [0.3.0] - 2022-02-01
### Changed
- Build: remove unneeded files from production build.
- Switch to pcov for code coverage.
- Updated package dependencies.
- Updated package textdomain from `jetpack` to `jetpack-post-list`.

## [0.2.4] - 2021-11-19
### Fixed
- Fixed the stretched thumbnails when using a non-square image.
- Fixed the broken layout after making a quick edit.

### Changed
- Updated package dependencies

## [0.2.3] - 2021-11-02
### Changed
- Set `convertDeprecationsToExceptions` true in PHPUnit config.
- Thumbnails only available on "Pages" and "Posts". Share action only when publicize and block-editor supported.
- Updated package dependencies.
- Update PHPUnit configs to include just what needs coverage rather than include everything then try to exclude stuff that doesn't.

## [0.2.2] - 2021-10-08
### Fixed
- Fixed the check for a valid thumbnail

## [0.2.1] - 2021-10-06
### Changed
- Updated package dependencies

## [0.2.0] - 2021-10-06
### Added
- Added a 'Share' post action

### Changed
- Only add the thumbnail column for post types that support it
- Updated package dependencies.

## 0.1.0 - 2021-09-22
### Added
- Add the new Post List package to Jetpack project

### Changed
- Updated the default columns displayed on the post and page list screens
- Refactored thumbnail preview to function server side. All javascript removed.

[0.8.31]: https://github.com/automattic/jetpack-post-list/compare/v0.8.30...v0.8.31
[0.8.30]: https://github.com/automattic/jetpack-post-list/compare/v0.8.29...v0.8.30
[0.8.29]: https://github.com/automattic/jetpack-post-list/compare/v0.8.28...v0.8.29
[0.8.28]: https://github.com/automattic/jetpack-post-list/compare/v0.8.27...v0.8.28
[0.8.27]: https://github.com/automattic/jetpack-post-list/compare/v0.8.26...v0.8.27
[0.8.26]: https://github.com/automattic/jetpack-post-list/compare/v0.8.25...v0.8.26
[0.8.25]: https://github.com/automattic/jetpack-post-list/compare/v0.8.24...v0.8.25
[0.8.24]: https://github.com/automattic/jetpack-post-list/compare/v0.8.23...v0.8.24
[0.8.23]: https://github.com/automattic/jetpack-post-list/compare/v0.8.22...v0.8.23
[0.8.22]: https://github.com/automattic/jetpack-post-list/compare/v0.8.21...v0.8.22
[0.8.21]: https://github.com/automattic/jetpack-post-list/compare/v0.8.20...v0.8.21
[0.8.20]: https://github.com/automattic/jetpack-post-list/compare/v0.8.19...v0.8.20
[0.8.19]: https://github.com/automattic/jetpack-post-list/compare/v0.8.18...v0.8.19
[0.8.18]: https://github.com/automattic/jetpack-post-list/compare/v0.8.17...v0.8.18
[0.8.17]: https://github.com/automattic/jetpack-post-list/compare/v0.8.16...v0.8.17
[0.8.16]: https://github.com/automattic/jetpack-post-list/compare/v0.8.15...v0.8.16
[0.8.15]: https://github.com/automattic/jetpack-post-list/compare/v0.8.14...v0.8.15
[0.8.14]: https://github.com/automattic/jetpack-post-list/compare/v0.8.13...v0.8.14
[0.8.13]: https://github.com/automattic/jetpack-post-list/compare/v0.8.12...v0.8.13
[0.8.12]: https://github.com/automattic/jetpack-post-list/compare/v0.8.11...v0.8.12
[0.8.11]: https://github.com/automattic/jetpack-post-list/compare/v0.8.10...v0.8.11
[0.8.10]: https://github.com/automattic/jetpack-post-list/compare/v0.8.9...v0.8.10
[0.8.9]: https://github.com/automattic/jetpack-post-list/compare/v0.8.8...v0.8.9
[0.8.8]: https://github.com/automattic/jetpack-post-list/compare/v0.8.7...v0.8.8
[0.8.7]: https://github.com/automattic/jetpack-post-list/compare/v0.8.6...v0.8.7
[0.8.6]: https://github.com/automattic/jetpack-post-list/compare/v0.8.5...v0.8.6
[0.8.5]: https://github.com/automattic/jetpack-post-list/compare/v0.8.4...v0.8.5
[0.8.4]: https://github.com/automattic/jetpack-post-list/compare/v0.8.3...v0.8.4
[0.8.3]: https://github.com/automattic/jetpack-post-list/compare/v0.8.2...v0.8.3
[0.8.2]: https://github.com/automattic/jetpack-post-list/compare/v0.8.1...v0.8.2
[0.8.1]: https://github.com/automattic/jetpack-post-list/compare/v0.8.0...v0.8.1
[0.8.0]: https://github.com/automattic/jetpack-post-list/compare/v0.7.3...v0.8.0
[0.7.3]: https://github.com/automattic/jetpack-post-list/compare/v0.7.2...v0.7.3
[0.7.2]: https://github.com/automattic/jetpack-post-list/compare/v0.7.1...v0.7.2
[0.7.1]: https://github.com/automattic/jetpack-post-list/compare/v0.7.0...v0.7.1
[0.7.0]: https://github.com/automattic/jetpack-post-list/compare/v0.6.5...v0.7.0
[0.6.5]: https://github.com/automattic/jetpack-post-list/compare/v0.6.4...v0.6.5
[0.6.4]: https://github.com/automattic/jetpack-post-list/compare/v0.6.3...v0.6.4
[0.6.3]: https://github.com/automattic/jetpack-post-list/compare/v0.6.2...v0.6.3
[0.6.2]: https://github.com/automattic/jetpack-post-list/compare/v0.6.1...v0.6.2
[0.6.1]: https://github.com/automattic/jetpack-post-list/compare/v0.6.0...v0.6.1
[0.6.0]: https://github.com/automattic/jetpack-post-list/compare/v0.5.1...v0.6.0
[0.5.1]: https://github.com/automattic/jetpack-post-list/compare/v0.5.0...v0.5.1
[0.5.0]: https://github.com/automattic/jetpack-post-list/compare/v0.4.6...v0.5.0
[0.4.6]: https://github.com/automattic/jetpack-post-list/compare/v0.4.5...v0.4.6
[0.4.5]: https://github.com/automattic/jetpack-post-list/compare/v0.4.4...v0.4.5
[0.4.4]: https://github.com/automattic/jetpack-post-list/compare/v0.4.3...v0.4.4
[0.4.3]: https://github.com/automattic/jetpack-post-list/compare/v0.4.2...v0.4.3
[0.4.2]: https://github.com/automattic/jetpack-post-list/compare/v0.4.1...v0.4.2
[0.4.1]: https://github.com/automattic/jetpack-post-list/compare/v0.4.0...v0.4.1
[0.4.0]: https://github.com/automattic/jetpack-post-list/compare/v0.3.1...v0.4.0
[0.3.1]: https://github.com/automattic/jetpack-post-list/compare/v0.3.0...v0.3.1
[0.3.0]: https://github.com/automattic/jetpack-post-list/compare/v0.2.4...v0.3.0
[0.2.4]: https://github.com/automattic/jetpack-post-list/compare/v0.2.3...v0.2.4
[0.2.3]: https://github.com/automattic/jetpack-post-list/compare/v0.2.2...v0.2.3
[0.2.2]: https://github.com/automattic/jetpack-post-list/compare/v0.2.1...v0.2.2
[0.2.1]: https://github.com/automattic/jetpack-post-list/compare/v0.2.0...v0.2.1
[0.2.0]: https://github.com/automattic/jetpack-post-list/compare/v0.1.0...v0.2.0

==> jetpack.15.3.zip: jetpack/jetpack_vendor/automattic/jetpack-post-list/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.8.34] - 2025-12-01
### Changed
- Update package dependencies. [#46143]

## [0.8.33] - 2025-11-17
### Changed
- Update package dependencies. [#45915]

## [0.8.32] - 2025-11-03
### Changed
- Update dependencies. [#45664]

## [0.8.31] - 2025-10-06
### Changed
- Update dependencies. [#45349]

## [0.8.30] - 2025-09-22
### Changed
- Update dependencies. [#44615]

## [0.8.29] - 2025-09-19
### Changed
- Update package dependencies. [#45173] [#45229]

## [0.8.28] - 2025-09-08
### Changed
- Update package dependencies. [#45027]

## [0.8.27] - 2025-08-14
### Changed
- Update package dependencies. [#44701]

## [0.8.26] - 2025-08-11
### Changed
- Update package dependencies. [#44677]

## [0.8.25] - 2025-08-04
### Changed
- Update dependencies. [#44583]

## [0.8.24] - 2025-07-28
### Changed
- Internal updates.

## [0.8.23] - 2025-07-21
### Changed
- Tests: Update class used in Slideshow block. [#44099]

## [0.8.22] - 2025-07-14
### Changed
- Update dependencies. [#44229]

## [0.8.21] - 2025-07-07
### Changed
- Update package dependencies. [#44148]

## [0.8.20] - 2025-06-30
### Changed
- Update dependencies. [#44061]

## [0.8.19] - 2025-06-23
### Changed
- Update dependencies. [#44002]
- Update package dependencies. [#44020]

## [0.8.18] - 2025-06-05
### Changed
- Update dependencies. [#43751]

## [0.8.17] - 2025-06-02
### Changed
- Update dependencies. [#43068]

## [0.8.16] - 2025-05-26
### Changed
- Update package dependencies. [#43578]

## [0.8.15] - 2025-05-22
### Changed
- Update dependencies. [#43068]

## [0.8.14] - 2025-05-05
### Changed
- Update package dependencies. [#43326]

## [0.8.13] - 2025-04-28
### Changed
- Internal updates.

## [0.8.12] - 2025-04-14
### Changed
- Update dependencies. [#43001]

## [0.8.11] - 2025-04-07
### Changed
- Linting: First pass of style coding standards. [#42734]
- Update dependencies. [#42820]
- Update package dependencies. [#42809]

## [0.8.10] - 2025-03-21
### Changed
- Internal updates.

## [0.8.9] - 2025-03-18
### Changed
- Update dependencies. [#42545]

## [0.8.8] - 2025-03-17
### Changed
- Internal updates.

## [0.8.7] - 2025-03-17
### Changed
- Social: Change the query parameter to open Jetpack sidebar on editor load. [#42364]

## [0.8.6] - 2025-03-12
### Changed
- Internal updates.

## [0.8.5] - 2025-03-10
### Fixed
- Exclude unit tests from published package. [#42190]

## [0.8.4] - 2025-03-03
### Changed
- Update package dependencies. [#42163]

## [0.8.3] - 2025-02-24
### Changed
- Update dependencies.

## [0.8.2] - 2025-02-17
### Changed
- Update dependencies.

## [0.8.1] - 2025-02-10
### Changed
- Updated package dependencies. [#41491]

## [0.8.0] - 2025-02-03
### Added
- Post List: Add a Copy Link Quick Action. [#41305]

## [0.7.3] - 2025-01-13
### Fixed
- Pages and Posts: Fix the layout on mobile when details are open. [#40872]

## [0.7.2] - 2024-12-16
### Changed
- Internal updates.

## [0.7.1] - 2024-11-25
### Changed
- Updated dependencies. [#40286]

## [0.7.0] - 2024-11-18
### Removed
- General: Update minimum PHP version to 7.2. [#40147]

## [0.6.5] - 2024-11-04
### Added
- Enable test coverage. [#39961]

## [0.6.4] - 2024-10-29
### Changed
- Internal updates.

## [0.6.3] - 2024-08-23
### Changed
- Updated package dependencies. [#39004]

## [0.6.2] - 2024-04-08
### Changed
- Internal updates.

## [0.6.1] - 2024-03-18
### Changed
- Internal updates.

## [0.6.0] - 2024-02-26
### Changed
- Social Notes: Added the post list enhancements [#35819]

## [0.5.1] - 2023-11-24
### Changed
- Replaced usage of substr() with str_starts_with() and str_ends_with(). [#34207]

## [0.5.0] - 2023-11-20
### Changed
- Updated required PHP version to >= 7.0. [#34192]

## [0.4.6] - 2023-08-28
### Changed
- Updated package dependencies. [#32605]

## [0.4.5] - 2023-04-10
### Added
- Add Jetpack Autoloader package suggestion. [#29988]

## [0.4.4] - 2023-02-20
### Changed
- Minor internal updates.

## [0.4.3] - 2022-12-06
### Changed
- Updated package dependencies. [#27688]

## [0.4.2] - 2022-11-28
### Changed
- Updated package dependencies. [#27043]

## [0.4.1] - 2022-09-20
### Changed
- Updated package dependencies.

## [0.4.0] - 2022-08-30
### Changed
- Rebrand Publicize to Jetpack Social [#25787]
- Updated package dependencies. [#25158]

## [0.3.1] - 2022-07-06
### Changed
- PHPCS: fix `WordPress.Security.ValidatedSanitizedInput`. [#23942]
- Renaming master to trunk. [#24661]
- Updated package dependencies. [#24045]

## [0.3.0] - 2022-02-01
### Changed
- Build: remove unneeded files from production build.
- Switch to pcov for code coverage.
- Updated package dependencies.
- Updated package textdomain from `jetpack` to `jetpack-post-list`.

## [0.2.4] - 2021-11-19
### Fixed
- Fixed the stretched thumbnails when using a non-square image.
- Fixed the broken layout after making a quick edit.

### Changed
- Updated package dependencies

## [0.2.3] - 2021-11-02
### Changed
- Set `convertDeprecationsToExceptions` true in PHPUnit config.
- Thumbnails only available on "Pages" and "Posts". Share action only when publicize and block-editor supported.
- Updated package dependencies.
- Update PHPUnit configs to include just what needs coverage rather than include everything then try to exclude stuff that doesn't.

## [0.2.2] - 2021-10-08
### Fixed
- Fixed the check for a valid thumbnail

## [0.2.1] - 2021-10-06
### Changed
- Updated package dependencies

## [0.2.0] - 2021-10-06
### Added
- Added a 'Share' post action

### Changed
- Only add the thumbnail column for post types that support it
- Updated package dependencies.

## 0.1.0 - 2021-09-22
### Added
- Add the new Post List package to Jetpack project

### Changed
- Updated the default columns displayed on the post and page list screens
- Refactored thumbnail preview to function server side. All javascript removed.

[0.8.34]: https://github.com/automattic/jetpack-post-list/compare/v0.8.33...v0.8.34
[0.8.33]: https://github.com/automattic/jetpack-post-list/compare/v0.8.32...v0.8.33
[0.8.32]: https://github.com/automattic/jetpack-post-list/compare/v0.8.31...v0.8.32
[0.8.31]: https://github.com/automattic/jetpack-post-list/compare/v0.8.30...v0.8.31
[0.8.30]: https://github.com/automattic/jetpack-post-list/compare/v0.8.29...v0.8.30
[0.8.29]: https://github.com/automattic/jetpack-post-list/compare/v0.8.28...v0.8.29
[0.8.28]: https://github.com/automattic/jetpack-post-list/compare/v0.8.27...v0.8.28
[0.8.27]: https://github.com/automattic/jetpack-post-list/compare/v0.8.26...v0.8.27
[0.8.26]: https://github.com/automattic/jetpack-post-list/compare/v0.8.25...v0.8.26
[0.8.25]: https://github.com/automattic/jetpack-post-list/compare/v0.8.24...v0.8.25
[0.8.24]: https://github.com/automattic/jetpack-post-list/compare/v0.8.23...v0.8.24
[0.8.23]: https://github.com/automattic/jetpack-post-list/compare/v0.8.22...v0.8.23
[0.8.22]: https://github.com/automattic/jetpack-post-list/compare/v0.8.21...v0.8.22
[0.8.21]: https://github.com/automattic/jetpack-post-list/compare/v0.8.20...v0.8.21
[0.8.20]: https://github.com/automattic/jetpack-post-list/compare/v0.8.19...v0.8.20
[0.8.19]: https://github.com/automattic/jetpack-post-list/compare/v0.8.18...v0.8.19
[0.8.18]: https://github.com/automattic/jetpack-post-list/compare/v0.8.17...v0.8.18
[0.8.17]: https://github.com/automattic/jetpack-post-list/compare/v0.8.16...v0.8.17
[0.8.16]: https://github.com/automattic/jetpack-post-list/compare/v0.8.15...v0.8.16
[0.8.15]: https://github.com/automattic/jetpack-post-list/compare/v0.8.14...v0.8.15
[0.8.14]: https://github.com/automattic/jetpack-post-list/compare/v0.8.13...v0.8.14
[0.8.13]: https://github.com/automattic/jetpack-post-list/compare/v0.8.12...v0.8.13
[0.8.12]: https://github.com/automattic/jetpack-post-list/compare/v0.8.11...v0.8.12
[0.8.11]: https://github.com/automattic/jetpack-post-list/compare/v0.8.10...v0.8.11
[0.8.10]: https://github.com/automattic/jetpack-post-list/compare/v0.8.9...v0.8.10
[0.8.9]: https://github.com/automattic/jetpack-post-list/compare/v0.8.8...v0.8.9
[0.8.8]: https://github.com/automattic/jetpack-post-list/compare/v0.8.7...v0.8.8
[0.8.7]: https://github.com/automattic/jetpack-post-list/compare/v0.8.6...v0.8.7
[0.8.6]: https://github.com/automattic/jetpack-post-list/compare/v0.8.5...v0.8.6
[0.8.5]: https://github.com/automattic/jetpack-post-list/compare/v0.8.4...v0.8.5
[0.8.4]: https://github.com/automattic/jetpack-post-list/compare/v0.8.3...v0.8.4
[0.8.3]: https://github.com/automattic/jetpack-post-list/compare/v0.8.2...v0.8.3
[0.8.2]: https://github.com/automattic/jetpack-post-list/compare/v0.8.1...v0.8.2
[0.8.1]: https://github.com/automattic/jetpack-post-list/compare/v0.8.0...v0.8.1
[0.8.0]: https://github.com/automattic/jetpack-post-list/compare/v0.7.3...v0.8.0
[0.7.3]: https://github.com/automattic/jetpack-post-list/compare/v0.7.2...v0.7.3
[0.7.2]: https://github.com/automattic/jetpack-post-list/compare/v0.7.1...v0.7.2
[0.7.1]: https://github.com/automattic/jetpack-post-list/compare/v0.7.0...v0.7.1
[0.7.0]: https://github.com/automattic/jetpack-post-list/compare/v0.6.5...v0.7.0
[0.6.5]: https://github.com/automattic/jetpack-post-list/compare/v0.6.4...v0.6.5
[0.6.4]: https://github.com/automattic/jetpack-post-list/compare/v0.6.3...v0.6.4
[0.6.3]: https://github.com/automattic/jetpack-post-list/compare/v0.6.2...v0.6.3
[0.6.2]: https://github.com/automattic/jetpack-post-list/compare/v0.6.1...v0.6.2
[0.6.1]: https://github.com/automattic/jetpack-post-list/compare/v0.6.0...v0.6.1
[0.6.0]: https://github.com/automattic/jetpack-post-list/compare/v0.5.1...v0.6.0
[0.5.1]: https://github.com/automattic/jetpack-post-list/compare/v0.5.0...v0.5.1
[0.5.0]: https://github.com/automattic/jetpack-post-list/compare/v0.4.6...v0.5.0
[0.4.6]: https://github.com/automattic/jetpack-post-list/compare/v0.4.5...v0.4.6
[0.4.5]: https://github.com/automattic/jetpack-post-list/compare/v0.4.4...v0.4.5
[0.4.4]: https://github.com/automattic/jetpack-post-list/compare/v0.4.3...v0.4.4
[0.4.3]: https://github.com/automattic/jetpack-post-list/compare/v0.4.2...v0.4.3
[0.4.2]: https://github.com/automattic/jetpack-post-list/compare/v0.4.1...v0.4.2
[0.4.1]: https://github.com/automattic/jetpack-post-list/compare/v0.4.0...v0.4.1
[0.4.0]: https://github.com/automattic/jetpack-post-list/compare/v0.3.1...v0.4.0
[0.3.1]: https://github.com/automattic/jetpack-post-list/compare/v0.3.0...v0.3.1
[0.3.0]: https://github.com/automattic/jetpack-post-list/compare/v0.2.4...v0.3.0
[0.2.4]: https://github.com/automattic/jetpack-post-list/compare/v0.2.3...v0.2.4
[0.2.3]: https://github.com/automattic/jetpack-post-list/compare/v0.2.2...v0.2.3
[0.2.2]: https://github.com/automattic/jetpack-post-list/compare/v0.2.1...v0.2.2
[0.2.1]: https://github.com/automattic/jetpack-post-list/compare/v0.2.0...v0.2.1
[0.2.0]: https://github.com/automattic/jetpack-post-list/compare/v0.1.0...v0.2.0
